@@ -1,6 +1,6 @@
 /* 
  * -- High Performance Computing Linpack Benchmark (HPL)                
- *    HPL - 2.2 - February 24, 2016                          
+ *    HPL - 2.3 - December 2, 2018                          
  *    Antoine P. Petitet                                                
  *    University of Tennessee, Knoxville                                
  *    Innovative Computing Laboratory                                 
@@ -174,6 +174,8 @@ void HPL_pdtest
                     "[%d,%d] %s", info[1], info[2],
                     "Memory allocation failed for A, x and b. Skip." );
       (TEST->kskip)++;
+      /* some processes might have succeeded with allocation */
+      if (vptr) free(vptr);
       return;
    }
 /*
@@ -248,7 +250,7 @@ void HPL_pdtest
 
       if( wtime[0] > HPL_rzero ) {
          HPL_fprintf( TEST->outfp,
-             "W%c%1d%c%c%1d%c%1d%12d %5d %5d %5d %18.2f     %18.3e\n",
+             "W%c%1d%c%c%1d%c%1d%12d %5d %5d %5d %18.2f    %19.4e\n",
              ( GRID->order == HPL_ROW_MAJOR ? 'R' : 'C' ),
              ALGO->depth, ctop, crfact, ALGO->nbdiv, cpfact, ALGO->nbmin,
              N, NB, nprow, npcol, wtime[0], Gflops );
@@ -409,7 +411,7 @@ void HPL_pdtest
       HPL_fprintf( TEST->outfp, "%s%s\n",
                    "----------------------------------------",
                    "----------------------------------------" );
-      HPL_fprintf( TEST->outfp, "%s%16.7f%s%s\n",
+      HPL_fprintf( TEST->outfp, "%s%16.8e%s%s\n",
          "||Ax-b||_oo/(eps*(||A||_oo*||x||_oo+||b||_oo)*N)= ", resid1,
          " ...... ", ( resid1 < TEST->thrsh ? "PASSED" : "FAILED" ) );
 
